<?php
/*
Plugin Name: eADV VIP
Plugin URI: https://www.eadv.it
Description: Plugin riservato ai publishers VIP di eADV
Version: 1.3.1
Author: TAGMOOD S.R.L.
Author URI: https://www.tagmood.it
*/

/**
 * In questo modo, quando viene richiesta la pagina /ads.txt, viene effettuato un redirect verso l'URL specificato utilizzando l'ID del sito impostato tramite una pagina di configurazione.
 */
function eadv_handle_ads_txt($wp)
{
    $request = isset($_SERVER['REQUEST_URI']) ? esc_url_raw(wp_unslash($_SERVER['REQUEST_URI'])) : false;
    $site_id = get_option('eadv_site_id');

    if ('/ads.txt' === $request && !empty($site_id)) {
        $url = 'https://panel.eadv.it/extads.txt?sid=' . $site_id;
        wp_redirect($url, 301);
        exit;
    }
}
add_action('init', 'eadv_handle_ads_txt', 1);

/**
 * Per inserire il codice javascript prima della chiusura del tag </body>, puoi utilizzare il hook di azione di WordPress wp_enqueue_scripts.
 */
function eadv_insert_javascript()
{
    $magic_code = get_option('eadv_magic_code_id');

    if (!empty($magic_code)) {
        $script_src = 'https://track.eadv.it/' . $magic_code . '.php';
        wp_enqueue_script('eadv_tracking_script', $script_src, array(), '', true);
    }
}
add_action('wp_enqueue_scripts', 'eadv_insert_javascript');

/**
 * Abilita il supporto TCF per Google Analytics
 */
function eadv_insert_gtag_enable_tcf_support()
{
    ?>
<script>
	window['gtag_enable_tcf_support'] = true;
</script>
<?php
}
add_action('wp_head', 'eadv_insert_gtag_enable_tcf_support', 1);

/**
 * Per inserire il <link> con preconnect nel tag <head></head> della pagina.
 */
function eadv_insert_preconnect()
{
    echo '<link href="https://track.eadv.it" rel="preconnect">';
}
add_action('wp_head', 'eadv_insert_preconnect');

/**
 * Nel tuo file principale del plugin, crea una funzione per aggiungere una nuova voce di menu nell'area di amministrazione di WordPress.
 */
function eadv_add_options_page()
{
    add_options_page(
        'eADV VIP Plugin Options',
        'eADV VIP',
        'manage_options',
        'eadv-vip-plugin',
        'eadv_options_page'
    );
}
add_action('admin_menu', 'eadv_add_options_page');

/**
 * Crea una funzione per la visualizzazione della pagina di opzioni.
 */
function eadv_options_page()
{
    ?>
<div class="wrap">
	<h1>eADV VIP</h1>
	<form method="post" action="options.php">
		<?php
    settings_fields('eadv_options');
    do_settings_sections('eadv-vip-plugin');
    submit_button();
    ?>
	</form>
</div>
<?php
}

/**
 * Registra le opzioni del plugin utilizzando la funzione register_setting.
 */
function eadv_register_settings()
{
    register_setting(
        'eadv_options',
        'eadv_site_id',
        array(
            'type' => 'string',
            'sanitize_callback' => 'sanitize_text_field',
            'default' => ''
        )
    );
    register_setting(
        'eadv_options',
        'eadv_magic_code_id',
        array(
            'type' => 'string',
            'sanitize_callback' => 'sanitize_text_field',
            'default' => ''
        )
    );
    register_setting(
        'eadv_options',
        'eadv_extra_options',
        array(
            'type' => 'string',
            'sanitize_callback' => 'sanitize_text_field',
            'default' => ''
        )
    );
}
add_action('admin_init', 'eadv_register_settings');

/**
 * Aggiungi una sezione per le opzioni del plugin utilizzando la funzione add_settings_section.
 */
function eadv_add_settings_section()
{
    add_settings_section(
        'eadv_section',
        'eADV VIP Plugin Settings',
        'eadv_section_callback',
        'eadv-vip-plugin'
    );
}
add_action('admin_init', 'eadv_add_settings_section');

/**
* Aggiunge CSS per il fix CLS
*/
function eadv_insert_css()
{
    $fix_cls_css = "<style>
    .eadv-billboard{min-height:100px;}@media screen and (min-width:990px){.eadv-billboard{min-height:250px;}}
    .eadv-in-content{min-height:400px;}@media screen and (min-width:990px){.eadv-in-content{min-height:250px;}}
    .eadv-aside{min-height:400px;}@media screen and (min-width:990px){.eadv-aside{min-height:600px;}}
    .eadv-related{min-height:900px;}
    .eadv-bottom{min-height:600px;}@media screen and (min-width: 990px){.eadv-bottom{min-height:250px;}}
    </style>";
    echo $fix_cls_css;
}
add_action('wp_head', 'eadv_insert_css');

/**
 * Replace degli shortcode per fix CLS
 */
function eadv_billboard_shortcode()
{
    return '<div id="eadv-billboard" class="eadv-billboard"></div>';
}
add_shortcode('eadv-billboard', 'eadv_billboard_shortcode');

function eadv_bottom_shortcode()
{
    return '<div id="eadv-bottom" class="eadv-bottom"></div>';
}
add_shortcode('eadv-bottom', 'eadv_bottom_shortcode');

function eadv_related_shortcode()
{
    return '<div id="eadv-related" class="eadv-related"></div>';
}
add_shortcode('eadv-related', 'eadv_related_shortcode');

function eadv_aside_shortcode($atts)
{
    // Imposta un valore predefinito per 'n' nel caso in cui non sia specificato
    $atts = shortcode_atts(array('n' => 1), $atts);
    $n = intval($atts['n']);

    return '<div id="eadv-aside'.($n > 1 ? '-'.$n : '').'" class="eadv-aside"></div>';
}
add_shortcode('eadv-aside', 'eadv_aside_shortcode');

function eadv_incontent_shortcode($atts)
{
    // Imposta un valore predefinito per 'n' nel caso in cui non sia specificato
    $atts = shortcode_atts(array('n' => 1), $atts);
    $n = intval($atts['n']);

    return '<div id="eadv-in-content'.($n > 1 ? '-'.$n : '').'" class="eadv-in-content"></div>';
}
add_shortcode('eadv-in-content', 'eadv_incontent_shortcode');


function eadv_section_callback()
{
    echo '<p>Imposta il plugin eADV VIP.</p>';
}

/**
 * Aggiungi i campi di input per le opzioni del plugin utilizzando la funzione add_settings_field.
 */
function eadv_add_settings_fields()
{
    add_settings_field(
        'eadv_site_id',
        'ID del sito',
        'eadv_site_id_callback',
        'eadv-vip-plugin',
        'eadv_section'
    );
    add_settings_field(
        'eadv_magic_code_id',
        'Magic code ID',
        'eadv_magic_code_id_callback',
        'eadv-vip-plugin',
        'eadv_section'
    );
    add_settings_field(
        'eadv_extra_options',
        'Extra Options',
        'eadv_extra_options_callback',
        'eadv-vip-plugin',
        'eadv_section'
    );
}
add_action('admin_init', 'eadv_add_settings_fields');

/**
 * Inserisce il placeholder [eadv-in-content n=xxx] dopo il primo paragrafo e poi ogni N paragrafi
 * L'opzione eadv_extra_options si trova nel formato opzione=valore
 * Nel caso specifico eadv-in-content=3, dove 3 indica la frequenza con cui inserire il placeholder all'interno del contenuto
 */
function eadv_insert_shortcode_every_n_paragraphs($content)
{
    if(!is_single() || (function_exists('is_amp_endpoint') && is_amp_endpoint())) {
        return $content;
    }
    $eadv_extra_options = get_option('eadv_extra_options');
    if (!empty($eadv_extra_options)) {
        $options = explode("\n", $eadv_extra_options);
        foreach ($options as $option) {
            $parts = explode("=", $option);
            if (count($parts) === 2 && trim($parts[0]) == 'eadv-in-content') {
                $n_freq = intval(trim($parts[1]));
                if($n_freq > 0 && $n_freq < 10) {
                    $paragraphs = preg_split('/<\/p>/', $content);

                    $paragraph_count = 0;
                    $placeholder_count = 0;
                    foreach ($paragraphs as &$paragraph) {
                        $paragraph_count++;
                        $paragraph = trim($paragraph);

                        // Check if it's time to insert the shortcode
                        if ($paragraph_count == 1 || (($paragraph_count - 1) % $n_freq === 0)) {
                            $placeholder_count++;
                            $paragraph .= '[eadv-in-content'.($placeholder_count > 1 ? ' n='.$placeholder_count : '').']';
                        }
                    }
                    // Rebuild the content with the inserted shortcodes
                    $content = implode('</p>', $paragraphs);
                }
            }
        }
    }
    return $content;
}
add_filter('the_content', 'eadv_insert_shortcode_every_n_paragraphs');


function eadv_site_id_callback()
{
    $value = get_option('eadv_site_id');
    echo '<input type="text" name="eadv_site_id" value="' . esc_attr($value) . '" />';
}

function eadv_magic_code_id_callback()
{
    $value = get_option('eadv_magic_code_id');
    echo '<input type="text" name="eadv_magic_code_id" value="' . esc_attr($value) . '" />';
}

function eadv_extra_options_callback()
{
    $value = get_option('eadv_extra_options');
    echo '<textarea name="eadv_extra_options" rows="4" cols="50">' . esc_html($value) . '</textarea>';
}

?>